# anns

[![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link]

anns is 

* an approximate nearest-neighbor search library for Python.



## Installation

```bash
pip install anns
```



## Quickstart

```python
import anns
```



## License

anns has a BSD-3-Clause license, as found in the [LICENSE](https://github.com/imyizhang/anns/blob/main/LICENSE) file.



## Contributing



## Changelog



[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/imyizhang/anns



[pypi_badge]: https://badgen.net/pypi/v/anns?icon=pypi&color=black&label
[pypi_link]: https://www.pypi.org/project/anns